@@ -1,8 +1,8 @@
 #
 # Mail/Salsa/Action/Admin.pm
-# Last Modification: Tue Nov 23 12:14:11 WET 2004
+# Last Modification: Tue Apr  5 12:01:12 WEST 2005
 #
-# Copyright (c) 2004 Henrique Dias <hdias@aesbuc.pt>. All rights reserved.
+# Copyright (c) 2005 Henrique Dias <hdias@aesbuc.pt>. All rights reserved.
 # This module is free software; you can redistribute it and/or modify
 # it under the same terms as Perl itself.
 #
@@ -33,15 +33,14 @@ our %EXPORT_TAGS = ( 'all' => [ qw() ] );
 
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw();
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 my @patterns = (
 	'[^\<\>\@\(\)]+',
-	'[^\@<>(),;:\s]+\@[^\@<>(),;:\s]+\.[a-zA-Z]{2,4}',
+	'[^\@<>(),;:\s]+\@([\w\-]+\.)+[a-zA-Z]{2,4}',
 	'(allow|deny) +(\S+) +to +(post|bounce|proceed) +from +(localnet|anywhere)(.+)?',
 );
 
-
 sub new {
 	my $proto = shift;
 	my $class = ref($proto) || $proto;
@@ -129,6 +128,7 @@ sub process_msg {
 
 sub normalize {
 	local $_ = shift;
+
 	if(/^($patterns[0]) +<($patterns[1])>\s+/) { return([lc($2), $1]); }
 	if(/^<?($patterns[1])>?\s+/) { return([lc($1), ""]); }
 	return(["", ""]);
@@ -570,7 +570,8 @@ __END__
 
 =head1 NAME
 
-Mail::Salsa::Action::Admin - Perl extension for blah blah blah
+Mail::Salsa::Action::Admin - Perl extension for administrate the mailing 
+lists.
 
 =head1 SYNOPSIS
 
@@ -607,7 +608,7 @@ Henrique M. Ribeiro Dias, E<lt>hdias@aesbuc.ptE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2004 by Henrique M. Ribeiro Dias
+Copyright (C) 2005 by Henrique M. Ribeiro Dias
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.2 or,
